from easy import audio
from easy import eagle

def play(app, button):
    audio.play(app['file_name'])
    audio.set_volume(10)

def pause(app, button):
    audio.pause()

def stop(app, button):
    audio.stop()

def record(app, button):
    audio.record(app['file_name'], 5, 0, rec_callback)

def record_async(app, button):
    audio.record(app['file_name'])

def rec_callback():
    # Define here your record callback
    pass

app = eagle.App(title='Easy Recorder', 
                #Now in Chinook, one must put the complete path. Do not uset ./
                top=eagle.Entry(id='file_name', value='/home/user/record.mp3'),
                bottom=(eagle.Button(id='record', label='Record',
                                     callback=record),
                        eagle.Button(id='rec_asyn',  label='Record Async',
                                     callback=record_async),
                        eagle.Button(id='stop', label='Stop', callback=stop),
                        eagle.Button(id='play', label='Play', callback=play)))

eagle.run()